@@ -10,7 +10,7 @@ class Premailer::TestCase < Minitest::Test
   def setup
     stub_request(:any, /premailer\.dev\/*/).to_return do |request|
       file_path = BASE_PATH + Addressable::URI.parse(request.uri).path
-      if File.exists?(file_path)
+      if File.exist?(file_path)
         { :status => 200, :body => File.open(file_path) }
       else
         { :status => 404, :body => "#{file_path} not found" }
